@@ -1,23 +1,19 @@
-from typing import Any, Dict, List, Optional, Type
 from inspect import signature
+from typing import Any, Dict, List, Optional, Type
 
 from fastapi import Depends, HTTPException, Path, Request
+from fastapi import Response as BareResponse
 from pydantic import BaseModel
 
 from maggma.api.models import Meta, Response
-from maggma.api.query_operator import (
-    PaginationQuery,
-    QueryOperator,
-    SparseFieldsQuery,
-)
+from maggma.api.query_operator import PaginationQuery, QueryOperator, SparseFieldsQuery
 from maggma.api.resource import Resource
 from maggma.api.resource.utils import attach_query_ops
-from maggma.api.utils import (
-    STORE_PARAMS,
-    merge_queries,
-)
+from maggma.api.utils import STORE_PARAMS, merge_queries, object_id_serilaization_helper
 from maggma.core import Store
 
+import orjson
+
 
 class ReadOnlyResource(Resource):
     """
@@ -36,6 +32,7 @@ class ReadOnlyResource(Resource):
         query: Optional[Dict] = None,
         enable_get_by_key: bool = True,
         enable_default_search: bool = True,
+        disable_validation: bool = False,
         include_in_schema: Optional[bool] = True,
         sub_path: Optional[str] = "/",
     ):
@@ -49,6 +46,9 @@ class ReadOnlyResource(Resource):
                 to allow user to define these on-the-fly.
             enable_get_by_key: Enable default key route for endpoint.
             enable_default_search: Enable default endpoint search behavior.
+            disable_validation: Whether to use ORJSON and provide a direct FastAPI response.
+                Note this will disable auto JSON serialization and response validation with the
+                provided model.
             include_in_schema: Whether the endpoint should be shown in the documented schema.
             sub_path: sub-URL path for the resource.
         """
@@ -59,6 +59,7 @@ class ReadOnlyResource(Resource):
         self.versioned = False
         self.enable_get_by_key = enable_get_by_key
         self.enable_default_search = enable_default_search
+        self.disable_validation = disable_validation
         self.include_in_schema = include_in_schema
         self.sub_path = sub_path
         self.response_model = Response[model]  # type: ignore
@@ -136,6 +137,12 @@ class ReadOnlyResource(Resource):
                 item = operator.post_process(item)
 
             response = {"data": item}
+
+            if self.disable_validation:
+                response = BareResponse(  # type: ignore
+                    orjson.dumps(response, default=object_id_serilaization_helper)
+                )
+
             return response
 
         self.router.get(
@@ -178,12 +185,21 @@ class ReadOnlyResource(Resource):
 
             count = self.store.count(query["criteria"])
             data = list(self.store.query(**query))
+            operator_meta = {}
 
             for operator in self.query_operators:
                 data = operator.post_process(data)
+                operator_meta.update(operator.meta())
 
             meta = Meta(total_doc=count)
-            response = {"data": data, "meta": meta.dict()}
+
+            response = {"data": data, "meta": {**meta.dict(), **operator_meta}}
+
+            if self.disable_validation:
+                response = BareResponse(  # type: ignore
+                    orjson.dumps(response, default=object_id_serilaization_helper)
+                )
+
             return response
 
         self.router.get(
