@@ -1,3 +1,3 @@
-from maggma.core import Builder
-from maggma.builders.map_builder import MapBuilder, CopyBuilder
 from maggma.builders.group_builder import GroupBuilder
+from maggma.builders.map_builder import CopyBuilder, MapBuilder
+from maggma.core import Builder
