@@ -4,6 +4,7 @@
 import json
 from asyncio import wait
 from logging import getLogger
+from socket import socket
 from typing import List
 
 from monty.json import jsanitize
@@ -15,15 +16,21 @@ from maggma.core import Builder
 from maggma.utils import tqdm
 
 
-async def master(url: str, builders: List[Builder], num_chunks: int):
+def find_port():
+    sock = socket()
+    sock.bind(("", 0))
+    return sock.getsockname()[1]
+
+
+async def manager(url: str, port: int, builders: List[Builder], num_chunks: int):
     """
-    Really simple master for distributed processing that uses a builder prechunk to modify
+    Really simple manager for distributed processing that uses a builder prechunk to modify
     the builder and send out modified builders for each worker to run
     """
-    logger = getLogger("Master")
+    logger = getLogger("Manager")
 
-    logger.info(f"Binding to Master URL {url}")
-    with Pair1(listen=url, polyamorous=True) as workers:
+    logger.info(f"Binding to Manager URL {url}:{port}")
+    with Pair1(listen=f"{url}:{port}", polyamorous=True) as workers:
 
         for builder in builders:
             logger.info(f"Working on {builder.__class__.__name__}")
@@ -61,21 +68,21 @@ async def master(url: str, builders: List[Builder], num_chunks: int):
         )
 
 
-async def worker(url: str, num_workers: int):
+async def worker(url: str, port: int, num_workers: int):
     """
-    Simple distributed worker that connects to a master asks for work and deploys
+    Simple distributed worker that connects to a manager asks for work and deploys
     using multiprocessing
     """
     # Should this have some sort of unique ID?
     logger = getLogger("Worker")
 
-    logger.info(f"Connnecting to Master at {url}")
-    with Pair1(dial=url, polyamorous=True) as master:
-        logger.info(f"Connected to Master at {url}")
+    logger.info(f"Connnecting to Manager at {url}:{port}")
+    with Pair1(dial=f"{url}:{port}", polyamorous=True) as manager:
+        logger.info(f"Connected to Manager at {url}:{port}")
         running = True
         while running:
-            await master.asend(b"Ready")
-            message = await master.arecv()
+            await manager.asend(b"Ready")
+            message = await manager.arecv()
             work = json.loads(message.decode("utf-8"))
             if "@class" in work and "@module" in work:
                 # We have a valid builder
