@@ -60,9 +60,7 @@ def test_sparse_query_serialization():
     with ScratchDir("."):
         dumpfn(op, "temp.json")
         new_op = loadfn("temp.json")
-        assert new_op.query() == {
-            "properties": ["name", "age", "weight", "last_updated"]
-        }
+        assert new_op.query() == {"properties": ["name", "age", "weight", "last_updated"]}
 
 
 def test_numeric_query_functionality():
@@ -71,10 +69,7 @@ def test_numeric_query_functionality():
 
     assert op.meta() == {}
     assert op.query(age_max=10, age_min=1, age_not_eq=[2, 3], weight_min=120) == {
-        "criteria": {
-            "age": {"$lte": 10, "$gte": 1, "$ne": [2, 3]},
-            "weight": {"$gte": 120},
-        }
+        "criteria": {"age": {"$lte": 10, "$gte": 1, "$ne": [2, 3]}, "weight": {"$gte": 120},}
     }
 
 
@@ -92,8 +87,8 @@ def test_sort_query_functionality():
 
     op = SortQuery()
 
-    assert op.query(field="volume", ascending=True) == {"sort": {"volume": 1}}
-    assert op.query(field="density", ascending=False) == {"sort": {"density": -1}}
+    assert op.query(sort_field="volume", ascending=True) == {"sort": {"volume": 1}}
+    assert op.query(sort_field="density", ascending=False) == {"sort": {"density": -1}}
 
 
 @pytest.mark.xfail
@@ -101,7 +96,7 @@ def test_sort_error():
 
     op = SortQuery()
 
-    op.query(field="volume")
+    op.query(sort_field="volume", ascending=None)
 
 
 def test_sort_serialization():
@@ -111,7 +106,7 @@ def test_sort_serialization():
     with ScratchDir("."):
         dumpfn(op, "temp.json")
         new_op = loadfn("temp.json")
-        assert new_op.query(field="volume", ascending=True) == {"sort": {"volume": 1}}
+        assert new_op.query(sort_field="volume", ascending=True) == {"sort": {"volume": 1}}
 
 
 @pytest.fixture
@@ -136,4 +131,3 @@ def test_submission_functionality(status_enum):
             ]
         }
     }
-
